.. _`units`:

Units
=====

The Data Dictionary specifies units for floating point and complex data nodes.
On the reference pages, units are indicated between square brackets.


Dimensionless units
'''''''''''''''''''

Dimensionless quantities have ``1`` indicated as their unit.


Use case dependent units
''''''''''''''''''''''''

Some quantities have use case dependent units, for example
:dd:node:`controllers/linear_controller/pid/p`. The units for these quantities are
indicated as ``mixed``.
